@@ -4,7 +4,7 @@
 
 (require snd-snd-motif.scm snd-examp.scm snd-extensions.scm snd-dsp.scm snd-draw.scm snd-env.scm snd-enved.scm)
 (require snd-hooks.scm snd-marks.scm snd-mix.scm snd-moog.scm snd-play.scm snd-rubber.scm snd-zip.scm snd-edit123.scm)
-(require snd-new-effects.scm snd-special-menu.scm snd-new-backgrounds.scm snd-marks-menu.scm snd-fft-menu.scm snd-effects-utils.scm)
+(require snd-new-effects.scm snd-special-menu.scm snd-marks-menu.scm snd-fft-menu.scm snd-effects-utils.scm)
 
 (with-let *motif*
 
@@ -13,10 +13,7 @@
 (if (not (hook-member show-disk-space after-open-hook))
     (hook-push after-open-hook show-disk-space))
 
-;(define wd (make-pixmap (cadr (main-widgets)) rough)) ; this comes from new-backgrounds.scm
-;(for-each-child (cadr (main-widgets)) (lambda (w) (XtSetValues w (list XmNbackgroundPixmap wd))))
-
-
+#|
 (let ((paint-all 
        (let ((wd (make-pixmap (cadr (main-widgets)) rough)))
 	 (lambda (widget)
@@ -41,6 +38,7 @@
   
   (if (not (hook-member hook-paint-all new-widget-hook))
       (hook-push new-widget-hook hook-paint-all)))
+|#
 
 (set! *mix-waveform-height* 32)
 
