@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "1-July-24"
+#define SND_DATE "5-Aug-24"
 #ifndef SND_VERSION
-#define SND_VERSION "24.5"
+#define SND_VERSION "24.6"
 #endif
 #define SND_MAJOR_VERSION "24"
-#define SND_MINOR_VERSION "5"
+#define SND_MINOR_VERSION "6"
 
 #endif
