@@ -1,12 +1,5 @@
 ;;; make-index.scm translated from index.cl
 ;;;   run this -noinit so that loads in ~/.snd_s7 don't confuse matters
-
-(when (provided? 'pure-s7)
-  (define (exact->inexact x)
-    (if (number? x)
-	(* x 1.0)
-	(error 'wrong-type-arg "exact->inexact argument should be a number: ~A" x))))
-
 (set! (*s7* 'heap-size) (* 2 1024000))
 
 (if (provided? 'pure-s7)
@@ -106,6 +99,7 @@
        (c (memq 'table commands) (memq 'table (cdr c))))
       ((not c) count)))
 
+
 (define (string</* a1 b1)
   (let ((a (ind-sortby a1))
 	(b (ind-sortby b1)))
@@ -455,7 +449,7 @@
       (for-each
        (lambda (binding)
 	 (when (pair? binding)
-	   (let ((symbol (car binding))
+	   (let ((sym (car binding))
 		 (value (cdr binding)))
 	     (when (and (procedure? value)
 			(let? (funclet value)))
@@ -474,21 +468,21 @@
 			   (set! pos k)))
 		     (let ((cur-names (hash-table-ref names file)))
 		       (if cur-names
-			   (if (not (memq symbol cur-names))
-			       (hash-table-set! names file (cons symbol cur-names)))
-			   (hash-table-set! names file (list symbol)))))))))))
+			   (if (not (memq sym cur-names))
+			       (hash-table-set! names file (cons sym cur-names)))
+			   (hash-table-set! names file (list sym)))))))))))
        e))
     
     ;; handle the main macros by hand
     (for-each
      (lambda (symbol-and-file)
-       (let ((symbol (car symbol-and-file))
+       (let ((sym (car symbol-and-file))
 	     (file (cadr symbol-and-file)))
 	 (if (not (file-exists? file))
-	     (format *stderr* ";~S says it is in ~S which does not exist\n" symbol file))
+	     (format *stderr* ";~S says it is in ~S which does not exist\n" sym file))
 	 
 	 (let ((cur-names (hash-table-ref names file)))
-	   (hash-table-set! names file (cons symbol (or cur-names ()))))))
+	   (hash-table-set! names file (cons sym (or cur-names ()))))))
      '((*libm* "libm.scm")
        (*libgdbm* "libgdbm.scm")
        (*libdl* "libdl.scm")
@@ -854,8 +848,8 @@
 		    (symbols (cdr ns)))
 		(set! size (+ size (length symbols)))
 		(for-each
-		 (lambda (symbol)
-		   (set! syms (cons (cons (symbol->string symbol) file) syms)))
+		 (lambda (sym)
+		   (set! syms (cons (cons (symbol->string sym) file) syms)))
 		 symbols))))
 	  (set! syms (sort! syms (lambda (a b) (string<? (car a) (car b)))))
 	  (format p "\nstatic const char *snd_names[~D] = {" (* size 2))
